PCB Environment: DRCViolation Class Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions
DRCViolation Class Reference

## Public Member Functions
| DRCViolation (Point_25, Connection *, Connection *, Pin *)
const Point_25 & | getLocation () const
Connection * | getConnection (uint i) const
PyObject * | getPy () const

The documentation for this class was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/DRC.hpp